---
title: "Protagoras, Homo Mensura, and Self Refutation"
date: 2022-08-31T02:04:51+01:00
tags: ["relativism","ontology","self-refutation"]
topics: ["metaphysics", "logic"]
image: img/Protagoras-Resized.jpg
description: An analysis of man as the measure of all things
draft: false
---
### Is *Homo Mensura* Self-Refuting?

Plato's Theaetetus involves a famous exchange between Socrates, an old mathematician named Theodorus, and his brilliant young pupil named Theaetetus, in which they attempt to answer the question of what is knowledge. The common denominator in this exchange, is that Protagoras is an old friend of Theodorus, and Theaetetus has adopted Protagorean relativism as his own doctrine. The exchange between Socrates and the two men is at least in part (in addition to attempting to discover a theory of knowledge in general) intended to demonstrate that the doctrine of Protagoras is self-refuting. This essay will provide a brief overview of the key interpretations of the doctrine of Protagoras, cover the basic arguments and their criticisms by various philosophers[^1], and then render a judgement (ironically?) in conclusion.

The first statement of the famous doctrine of Protagoras comes just before 160e in the dialogue: "*that man is the measure of all things*". But the work of analysing what that means does not really begin until 161c-d, where it is restated as: "*a thing is, for any individual, what it seems to him to be*"[^2] In his initial objection, though, Socrates rapidly restates the thesis in yet other new ways: "*whatever the individual judges by means of perception is true for him*", and "*only the individual himself can judge of his own world*", and "*what [a man] judges is always true and correct*", and again later at 162d, "*a thing is for each man what it seems to him to be*".

Each of these restatements connotes a different sense of the doctrine, and sometimes, even a different meaning. In offering up all these restatements, it is unclear whether Plato is attempting to grapple with the concept, or to lampoon it. Just before this, Socrates is asking why Pig is not the measure of all things, which is clearly meant as a jibe. Indeed, at one point, Socrates pokes fun at himself by referring explicitly to Protagoras coming back from the dead to chastise him, for his straw men. Still, as Fine (1998) points out, nothing of the real Protagoras survives to modern day. So, all we can do is work with what Plato has given to us. If that's good enough for his portrayal of Socrates himself, then it should be good enough for his portrayal of Protagoras (who, by the way, elsewhere gets his own eponymous dialogue as well).

So, assuming these various restatements of the measure doctrine are good faith attempts to understand it precisely, they could be classified into three broad categories:

1. What Burnyeat (1976) calls "private worlds"

2. What Fine characterises as Burnyeat's theory of belief

3. What is typically called *alethic relativism*

The task at this point, is to examine each interpretation, determine if it makes sense for Protagoras to intend for that interpretation of his theory, and if so, if that interpretation would bind him to a self-refuting theory or not.

### Private Worlds

The first interpretation is a relativism that derives its ontology in part from the radical eliminativist (or 'process ontology') view of Heraclitus, who's presence is large in this dialogue. Namely, that reality (if that word can be used) consists in no stable objects, not even selves. There is only "flow" or "flux", which is in constant motion, and at indeterminate and ephemeral moments, that flux coalesces into an experience had by a subject. Fine (1998) paraphrases Burnyeat's understanding in much more concrete terms, using Socrates' example of the wind:

> "*each of us lives in a private world in the sense that the objects I have access to are different from the objects you have access to, and none of these private objects persists for longer than a moment. So, when I say that the wind is cold and you say that it is not, we do not contradict one another, since we are talking about different winds... Whatever I say about the objects in my world, is true of those objects, and whatever you say about the objects in your world is true of those objects.*"

On this view, Protagoras is arguing that every subject has his own objects, and as such, any assertion about those objects would be necessarily true because no two subjects share the same objects, and no perception by any subject could be a perception of anything but that subject's  objects. But it is not at all clear how, in the process ontology of Heraclitus, there could be such stable things as "each of us", and "subjects", and "objects" and "I" and "you" and "the world", let alone say anything true about them. Fine (and presumably Burnyeat) are describing all more-or-less stable identities, that not only persist but in the case of rational perceivers, include a memory of that persistence.

Protagoras himself (through the mouth of Socrates), does seem to suggest the more 'solid' Heraclitean 'private world', at 166c:

> "*...Show a little more spirit, my good man,' he will say, 'and attack my actual statement itself, and refute it, if you can, by showing that each man's perceptions are not **his own private events**; or that, if they are **his own private events**, it does not follow that the thing which appears 'becomes' or if we may speak of being, **'is' only for the man to whom it appears**...*" [emphasis added]

But he does go further in the same passage, to suggest a kind of ontological power over the objects in that private world, at 166d:

> "*...the man whom I call wise is the man who can change the appearances -- the man who in any case where bad things both appear and are for one of us, works a change and makes good things appear and be for him...*"

Now, not only are we talking about two different winds, one for you and one for me. Not only are we talking about two different seemings, one wind cold, and one wind hot. Now, we are talking about the power to make the wind that *is and feels* cold for me *feel and be* warm for me. Is that what Protagoras means when he lauds those who 'work a change' and 'make' good things appear for them? This seems a bit too far a stretch. In fact, in the context of Plato's ongoing criticism of the Sophists, it might be suggested that this is actually just an allusion on Plato's part, to their very condemnation: those who make the worse appear the better. What's more, in the same passage (just a paragraph later at 166e), the healthy man and the sick man do not seem to possess this magical power, despite their living in two different alethic universes.

Thus far, "private worlds" interpretation is plausible, as far as trying to understand what Protagoras is positing in the measure doctrine. But it doesn't last long. Because as soon as Protagoras (via Socrates) establishes two incommensurable private universes, he thus proceeds to collapse them into a categorically different unity at 167a:

> "*What  we have to do is to make a change from the one [the sick] to the other [the healthy], because the other state is **better**. In education, too, what we have to do is to change the **worse** state into the **better** state; only whereas the doctor brings about the change by the use of drugs, the professional teacher [Sophist] does it by use of words. What never happens is that a man who judges what is false is made to judge what is true... when a man's soul is in a pernicious state, he judges things akin to it, but giving him a sound state of the soul causes him to think different things, things that are good. In the latter event, the things which appear to him are what some people, who are still in a primitive state, call 'true'; my position, however, is that the one kind are **better** than the others, but in no way truer*"

What Protagoras now wants to do, is to make a distinction between *truth* and *goodness*, and to say that truth is relative, but goodness is universal. For, how else are we to judge the *better* and the *worse*, without appeal to some objective standard, which is shared by both the sick and the healthy man, and the judge? The Protagoras that Socrates has constructed is saying that we should move the sick man to health, and when we do, then what is true *for him* will correspond to what is *better*. The sick man's food is bitter. The healthy man's food is savoury. Savory is better than bitter. Job done.

The point here, is that on this reading, the "private worlds" interpretation of Protagoras requires Protagoras to engage in *two opposing theories at once*: both relativism and absolutism. They're not contradictory in the strictest sense, since they point to different categories of reality. But they are uncomfortably inconsistent. Relativism about ontological truth, absolutism about normative judgement. The original doctrine states that man is the measure of *all* things. So, would that not include normative judgements of better and worse? In other words, in the same way that something is *true for A*, can it not also be said that something is *better for A*? If not, why not? Protagoras offers no explanation.

What's more, the second half of the doctrine says (152a): "*of the things which are, that they are, and of the things which are not, that they are not*". So, it also makes little sense to ascribe the properties of sickness and health to a man, since it is not up to anyone but that man whether he is sick or healthy. He is his own measure. What is the doctor doing, exactly? If the application of medicines does *in fact* move a man from sickness to health, then the doctor is engaging in an objective exercise, and Protagoras is incorrect. But if it is up to the patient to decide for himself whether he is sick or healthy, then the doctor is merely engaging in some sort of sympathetic pandering. Likewise for the "professional teacher". The point is, that the normative judgements about states requires factual judgements about states. It makes no sense for me to say you are better or worse off, if I can say nothing about whether you are healthy or sick. Even if I rely on you to relay to me your status, I am in no position to offer up a normative judgement of that status. What would it even mean for me to say one is better than the other?

So, in the end, the "private worlds" understanding of the doctrine of Protagoras is incoherent. If this is indeed what Protagoras intended, then his doctrine is indeed refuted. However, if this is not what Protagoras intended, then we must proceed to examine the other possible interpretations. As mentioned before, we cannot really know what Protagoras intended. So, we rely on Plato to relay it to us through the mouth of Socrates. That being the case, proceeding is a necessity.

### Truth As Belief

Fine (1998) makes a further distinction, arguing that Burnyeat (1976) has two interpretations of the "private worlds" theory. The first, as a literally true representation of Heraclitean ontology, which we have just addressed. The second, as a metaphor for belief. This second interpretation needs further explanation. Part of the dispute between Burnyeat and Fine, is whether or not interpretations (2) and (3) above are *synonymous*. In other words, when I say "X is true for me", all I am really saying, is "I believe that X"; the meaning of the latter exhausts the meaning of the former. To put it more plainly, truth is not conditioned by a perception or impression, but by *belief*. Fine takes Burnyeat to be suggesting this theory as an interpretation of Protagoras, partly from this passage in the Burnyeat essay:

> "*Why is it an objection to Protagoras that, on his own showing, if no on believes his theory it is not true for anybody? Protagoras might for various reasons be embarrassed to admit this, but would he be refuted? Is it so surprising that a theory according to which all truth is relative to belief should itself be no more than a relative truth, true only for someone who believes it?*"

The key phrase here is "relative to belief". For this to work, however, requires taking the various words used by Socrates and Theaetetus -- "seems", "appears", "judges", and "percieves" -- to be varieties of *belief* rather than kinds of sense experiences; or rather, are *snynonymous* with sense experiences. As Fine puts it:

> *[Burnyeat] says that appearances are true; and it is beliefs [about e.g. apples], rather than things like apples, that are true... If a person's world is constituted by her appearances, and if appearances are just beliefs, then the notion of a person's world is just a metaphor for a person's beliefs...*

Fine's understanding of Burnyeat matches my own. The central question here, however, is not to adjudicate the dispute between Fine and Burnyeat. Rather, it is the question of whether the belief interpretation of Protagoras' measure doctrine makes any sense. The hope was that one of the two would provide a clear answer in an example from the text. However, neither seems to have spent much space in their essays on the actual text of the Theaetetus, in disputing this point.

What can be found in the text, however, is not an iteration of the doctrine cast in terms of belief, but lots of uses of the word belief, which carry the connotation of *confidence in an opinion*, or *commitment to a truth*. In Socrates first serious engagement with Theodorus, for example, the word suddenly pops up no less than four times (170a-c):

> "*...there is no one in the world who doesn't believe that in some matters he is wiser than other men... you find also men who believe that they are able to teach... men do believe in the existence of both wisdom and ignorance... they believe that wisdom is true thinking...*"

There are two ways to read these statements. First, as Socrates making assertions about what all men take to be true *for themselves*. The second, as Socrates making assertions about what is true *of what all men take to be true*.  I think the latter interpretation makes more sense coming from Socrates. It is the statement that for all men M, M implies belief (a | b | c). And it is either true or false *simpliciter*, based on the substitutions. The former interpretation is the way in which Protagoras would formulate the case. However, the problem here is whether we can take those *men's beliefs* to be synonymous not just with *truth claims*, but with the *truth*. In other words, When Socrates says that all men believe that wisdom is true thinking, is it then the case that *it is true* that wisdom is true thinking? or is it merely the case that it is true *that all men believe* that wisdom is true thinking? If the former, then we have a theory of belief as truth. If the latter, then we do not have such a theory. We just have Socrates trying to make a universal generalization look like an absolute.

The latter is the more convincing interpretation in the context in which these passages are found. If that is the case, it might provide one explanation for the apparent attempt to "sneak" absolutes into statements of Protagorean relativism (creating a question-begging situation), found in many modern criticisms of this part of the argument. In other words, it is precisely what Plato or Socrates would have presumed to be the case: that truth is absolute, and it can be seen in the fact that some facts seem to be accepted universally. But also, more importantly for the investigation here, it renders the belief interpretation much less convincing than it had seemed at first. Protagoras would indeed not have accepted this presumption. He would have insisted on the "for themselves" formulation of Socrates assertions. Since this interpretation fails that first test, we need not bother with examining it against the second test of whether it binds Protagoras to a self-refutation. As such, we move to our third interpretation.

### Alethic Relativism

Earlier, we saw how the radical subjectivism of the "private worlds" interpretation turned out to be both untenable, and probably not the view of Protagoras, and we have just seen how the equation of truth and belief is probably also not the view of Protagoras. This leaves us with Alethic Relativism, as the only remaining possibility.

The basic idea of alethic relativism, is that what is true for one, may not be true for another, and as put by Baghramanian and Carter (2022), "*there is no context-independent vantage point to adjudicate the matter. What is true or false is always relative to a conceptual, cultural, or linguistic framework.*" While this turn of phrase looks nearly identical to the concept considered in the "private worlds" section, there is one significant change. It does not posit independent, incommensurable "worlds" which function as the subject-dependent truth-makers for truth claims about those worlds. Instead, what is asserted is that the predicate "is true" is a deceptive two-place term which always includes (hidden or not) a term qualifying the first. There is no requirement that the correspondence take place in a unitary reality. More to the point, the correspondence ocurring between a subject and any given slice of a unitary reality need not be the same correspondence taking place between any other subject and that unitary reality. To borrow a phrase common in pop culture today, something can be true "*from a certain point of view*".[^3]

On this understanding, the example of the doctor and the professional teacher make much more sense. Now, instead of incommensurable individual worlds, it is possible to construct social realities out of agreements between individuals, and pragmatism can function as a substitute for aletheia. Indeed, this is precisely the point of what Burnyeat (1990) calls the "New Formulation". The sick man and his doctor come to an agreement about the doctor's expertise, and what constitutes a better state of health, and they engage in the project together. Whether or not that project would work for anyone else is irrelevant, and not conducive to the present concern. But that capacity to engage socially requires a common reality in which the two can meet and negotiate terms.

Burnyeat (1990) uses the dialectic around "advantage" to make this point, and in his footnotes, says "the New Formulation employs a somewhat different vocabulary from the Defence. The key word in the Defence was chrestos, translated 'sound', 'wholesome'. This is now replaced by 'sumphereon', 'advantageous', or 'in one's interest'.." It's the "*in one's interest*" part that is most interesting, here. This suggests precisely, the "*true for me*" formulation of the early statements of the doctrine. But, it's framed in terms of what is *valued* rather than *what is judged true*.

If we trust Plato, that what Protagoras intended was a theory not of relative truth, but of *relative value*, then Alethic Relativism is not at all the right characterization of the theory, but rather, *moral* relativism. But this would mean we should have seen all sorts of examples in the dialogue of *value* comparisons, of the relative meanings of good and bad, and of better and worse. Yet, they do not come until just before the Digression, and then, only in relation to *practical* advantage (as in the city), or personal health. Let us recall that the original statement was that "man is the measure of all **things**" and the judge of what **is** and **is not**. These are ontological assertions, not deontological.

Thus, the Alethic Relativist position seems the most reasonable interpretation of Protagoras' position. What remains to be discovered, then, is whether or not Plato has shown his doctrine, *understood as Alethic Relativism*, is self-refuting. Here, again, I am relying on Baghramanian and Carter (2022) for the sake of a concise statement of my own understanding. They summarize the argument at 171a-c as such:

1. Most people believe that Protagoras' doctrine is false

2. Protagoras believes his doctrine to be true

3. Protagoras must believe his oppnonents view is true (because of 2)

4. Therefore, Protagoras must believe that his own doctrine is false (which contradicts 2)

As Fine and Burnyeat have both rightly pointed out, this formulation of the argument is lacking the two-term predicate, without any justification for omitting it. Thus, it is an obvious case of question-begging. If reconstructed with the two-term predicate, we would have the following:

1. Most people believe that Protagoras' doctrine is false *for them*

2. Protagoras believes that his doctrine to be true *for him*

3. Protagoras must believe that his opponents view is true *for them* (that they think the doctrine is false, for them)

4. Therefore, Protagoras must believe that his own doctrine is false *for them* (reaffirming 1)

On this formulation, the argument is valid and non-question-begging, but simply affirms Relativism by example. So, at long last, we can finally see that it is straightforward that Plato has *not* shown that the Protagorean doctrine of *homo mensura* is self-refuting.

## Conclusion

There are a number of lingering questions i have about this analysis. First, I cannot help but wonder what sense it makes to construct an analytical criticism of a relativist doctrine. The whole project seems non-sensical. Analytical criticism relies for its credibility on the presumption of the  authority of logic, which is grounded in the correspondence theory of truth, which in turn assumes absolutism (in such things as the law of the excluded middle, and the law of identity). I suppose it might be possible to rewrite the analysis from the perspective of a coherence theory, beginning with certain fundamental axioms we might be able to derive from the dialogue. But then, the danger is that we'd just be engaging in a circular affirmation of the assertions of the Protagorean doctrine. So, it is not at all clear to me how much value an analysis like this (or indeed, even Fine's or Burnyeat's), even has.

Secondly, I am dogged by the nagging sense that the entire dialogue is a red herring. If one looks at the vast majority of examples provided, when considering whether something is "true for me", we get a range of highly subjective qualities like taste and touch. Food is savory or bitter. Wind is cold or warm. Where they are less subjective, they are still controversial. A stone is white, and so forth. The point I'm driving at here, is that the assertions being made are not actually *about the objective world*. They're about the qualitative sense experience of that world. If Plato had been able to make the distinction between an objective property, and a subjective qualia, then perhaps this entire dialogue would have been rendered moot. In other words, the fruit is not sweet. The fruit just *is*, and when I put it on my tongue, sweetness happens to me. From an objective point of view, there is a reductive biochemical interaction that can be supplied as an explanation. Thus, there is no longer any conflict between the way the world *seems to me*, and the way the world really is.

Thirdly, why is Socrates tasked with providing a defense of Protagoras? Why not Theodorus? Why does Theodorus put up such a resistance? The script itself offers up a few superficial excuses. Theodorus is old and tired, Theodorus doesn't understand dialectic, Theodorus doesn't want to besmirch his dead friend, and so forth. For that matter, why not just have Protagoras himself? As noted above, he has his own eponymous dialogue. Why not one more (after all, Alcibiades got two). I think there is something dramatically devious about putting the defense of relativism in the mouth of an Platonic realist and an absolutist. It lends the relativist a degree of authority he would not otherwise have. It also puts the absolutist in the position of offering up back-handed alethic realism defenses for relativism itself. In other words, Socrates refutation of alethic relativism can simply be compartmentalized as yet another set of views one could hold relatively: the absolutist set.

Finally, while I do think this shows that Plato's refutation is insufficient, I'm not convinced this means Protagorean Relativism is true. Not even "true for me". But that thought alone, breaks the necessity of binary logic. If it's not untrue, and it's not true, then what is it? All of this suggests that something rather important is missing from my understanding of the problem. I wish I knew what that was.

[^1]: For the sake of brevity, I have restricted my analysis to a summary of the debate between Myles Burnyeat and Kit Fine. Additional sources were examined, but references will largely be from their three papers. The reference list at the end will include all research.

[^2]: In other translations, this is cast as "what appears is" (Jowett), and "what appears to each one is to him" (Tufts). The reason I'm rasing this concern, is because there seems to be quite a lot of dispute between Burnyeat, Fine, and others, about precise meanings of words like "seems", "appears", and "perceives", and the use of phrases like "seems to X" or "true for X". Depending on the translation, you get all of these, some of these,  or none of these. For my part, I am using the Hackett (Levett) because that is what was recommended for the class, but it will obviously color the analysis.

[^3]: Star Wars: Return of the Jedi, 1983. The ghostly Obi Wan Kenobi explains to Luke Skywalker why he originally told Luke that his father was dead, even though Obi Wan knew his father was not dead. 
