---
title: "John Locke's Property Rights"
date: 2020-06-05T21:48:41Z
tags: ["ethics","natural law","government","property rights"]
topics: ["philosophy","politics"]
image: img/john-locke-wide.jpg
draft: false
---

Does Locke offer a convincing account of an individual’s right to property? In his Second Treatise on Government, John Locke constructs a theory of property rights from two explicit arguments for the divine source of the moral claim of ownership, and one implicit argument for the divine source of value in labor. This essay will summarize each of these arguments, offer an assessment of the three arguments in combination, and conclude that Locke’s case is unconvincing in isolation. However, there are remedies which could make the case more convincing.

The first of the three arguments begins with an exegesis of passages of Genesis. Locke concedes that we could only conclude that God’s initial grant of dominion over nature, from the story of the Garden of Eden, was a grant in common to all humanity, and not merely a right of absolute rule granted to Adam’s successors, or an open license to private acquisition by individuals. This may seem like a problem for Locke, but he goes on to argue from the story of The Fall, that when God cursed man to scrape his living out of the soil by the sweat of his brow, he implicitly granted men an implicit right to appropriate as much from nature as was necessary to the achievement of that living. He says that, were this not the case, then God would have left us in a double-bind: forced to live in a continual state of injustice by appropriating the common inheritance for our own self-preservation, or starving to death for the sake of justice. Thus, at a minimum, we must have a right to appropriation for the sake of self-preservation, granted implicitly to us by God, when he condemned us to live off the land.

The second argument picks up where the first left off. Locke argues that this right of self-preservation is evident in our impulse to survive. God would not have imbued us with a desire to preserve ourselves, if he had not intended for his creation to endure. God, being the creator of man, has an absolute right of property over us, and obeying the impulse to self-preservation is thus an imperative to respect his right of ownership over his creation. The next move in this argument is to say that this imperative implies self-ownership in each individual by virtue of the fact that the impulse is personal (rather than common), and the fact that God’s absolute ownership over each individual precludes the possibility of any individual claiming ownership over any other individual. That self-ownership thus implies ownership of the actions of the self by way of common sense, and by extension, responsibility for the products of those actions. It is in that responsibility, that property rights arise.

Finally, Locke claims that “something is mixed” with what we appropriate from nature, when we manipulate it to proper ends (the end of self-preservation). That “something”, is typically described as our labor. But this seems too superficial an understanding. If that were all Locke had to say about it, his argument would be weak indeed. Rather, it is not the labor as such that is “mixed”, but something intangible generated by the labor. That something seems to be an imputed value in the effort employed in transforming nature into a product. That value, by extension, entails an implicit moral claim to exclusive control over the result of our effort. Appealing again to biblical justifications, Locke claims that God’s grant to take what we need is limited to that *which we thus improve*. It is in that improvement, that the right of property inheres in the possession. This, in combination with the responsibility inferred in the second argument, offers a compound case of both material necessity and moral obligation, for the right of private property.

Locke’s skill as a logician is, in some ways, his own worst enemy. The clarity of his syllogistic style of writing makes the problems in his arguments crystal clear. It is one thing to ask whether his arguments are syllogistically valid (most of which are, in fact). It’s quite another to ask whether his arguments are *convincing*. What does Locke need to be convincing? The criteria for that is much broader than it would be for logical analysis and brings in a number of external concerns that significantly weaken the strength of his case.

To begin with, why should we take biblical exegesis seriously as a basis for the major premises in his case for the moral claim of property? If we were judging relative only to the poor sop he throttled in his First Treatise, then he certainly has the much stronger scriptural case. But again, why should I take the myth of The Fall and The Flood as basis for the moral authority for property? For that matter, what justification is there to accept the existence of the God found therein? Now, it is true that, absent that God, and absent those scriptural justifications, we would be hard pressed to find new ground on which to stand if we wanted to preserve property. But that would be to defend Locke on the basis of an appeal to anxiety provoking consequences. This author might be willing to grant the premises, but what about the rest of the world? Thus, the most significant of Locke’s major premises radically undermine his own case, with audiences that are not already predisposed to take them for granted.

The second problem with Locke’s case, lies in the transference claims. Even if we grant exegetical justifications, there are a number of places where scripture would challenge his claim that ownership of self can be inferred from God’s ownership of the souls he creates. He is probably correct about the fact that we have no authority to claim ownership over one another, based on divine dominion, but many theologians (even in his own time) would claim that we are not independently autonomous (self-owning). We are *subjects* of God, serving at his pleasure, and as such, no autonomous ownership could be inferred, any more than the subjects of a terrestrial king could claim to be autonomous of the king’s edicts. In addition to this, the transference of the moral claim of ownership over actions to ownership over products is dubious without a theory of moral agency. Now, Locke might have had one himself. But he did not specify it in this treatise. But without that theory, it is not clear either how responsibility is assigned, or how ownership over products is inferred from that responsibility. Given how much scriptural support Locke provided in his critique of Robert Filmer, surely he could have mustered something in defense of biblical free will?

Lastly, we move on to Locke’s third argument. While his case for labor-mixing is superficially compelling, it turns out to be missing an essential insight. Namely, value is not conferred by labor alone. Locke is (perhaps unintentionally) overestimating the contribution of the creator, in the process of “improvement”. Locke offers two examples to illustrate his case. First, is 100 acres of cultivated wheat. The second, is 100 acres of fallow woodland. In the first case, he claims, the improvement made by the landholder gives it it’s value, because its product is conducive to the end of self-preservation. But, curiously, Locke seems to only be referring to the farmer himself. What would the farmer need, himself, with 100 acres of harvestable wheat? No single human being could possibly consume all that in the form of bread flour, even over the course of an entire winter. Now, imagine, instead of 100 acres of wheat, the farmer had cultivated 100 acres of dandelions (or whatever your favorite noxious weed is). This makes the problem much more vivid. Despite nearly identical amounts of labor in plowing, fertilizing, tending, and harvesting, the wheat field would have orders of magnitude more value than the dandelion field. Why? Because of the need of others, not the effort of the farmer. Value is imbued in a product by a process of combining what the farmer is willing to spend his effort on, **and** what the consumer is willing to trade for it. In other words, “improvement” is determined by a criteria of negotiation between the producer and those who seek his products, not exclusively by the producer. As such, that value could not be traceable exclusively to an obligation to God, but would be a mixture itself, of divine obligation and social agreement.

What is interesting about this insight, is that Locke could have grounded the third argument in his own principle of natural proportional reciprocity (one of the Laws of Nature he enumerated). When the farmer estimates the expense of his effort and it coincides with the estimate of, say, the baker’s desire for flour for his bread, they are able to benefit each other in equal measure. What’s more, if the baker hired goons to appropriate the wheat from the farmer in the dead of night, the farmer could complain of injustice on the basis of a violation of reciprocity. No appeal to divine authority would be needed in such a case, beyond the justification of the Law of Nature itself. The state would also have the benefit of empirical grounds for determining the amount of retributive justice needed to reconcile the two.

This dual-source understanding of value would outfit the farmer with multiple justifications for sharing his produce, since the exchange of value would be isomorphic (if you will). The farmer need not rely entirely on his altruistic instinct to serve the “common good”. He would see explicitly what share he has in the common good, by way of the pricing (or bartering) mechanism that tokenizes the negotiated estimates of value. Without a notion of property, this kind of negotiation would be impossible.

Ultimately, Locke’s theory of property will only be convincing to those who already accept the religious foundations of his arguments – that we are creations of God, that our participation in the ‘divine spark’ makes us all valuable in an absolute sense, and that the work we do to satisfy the conditions of the divine penury derived from The Fall – naturally transfigure our possessions into property. This is unfortunate, because as I have shown in at least the case of reciprocity, there are ways to make the case for Natural Law that do not entirely rely on scripture or divine mandate. A more naturalistic rendition of Locke’s theory might thus be more convincing to a broader audience.

```[Imported from extingthecave.com on 28 November 2021]```

